.. _api_reference:

API Reference
=============

.. _core_modules_api_index:

Core Modules
------------

.. autosummary::
   :nosignatures:
   :toctree: api/
   :template: module_summary_private.rst

   wags_tails.base_source
   wags_tails.custom

.. _sources_modules_api_index:

Data Sources
------------

.. autosummary::
   :nosignatures:
   :toctree: api/sources/
   :template: module_summary_inh.rst

   wags_tails.chembl
   wags_tails.chemidplus
   wags_tails.do
   wags_tails.drugbank
   wags_tails.drugsatfda
   wags_tails.ensembl
   wags_tails.ensembl_transcript_mappings
   wags_tails.guide_to_pharmacology
   wags_tails.hemonc
   wags_tails.hgnc
   wags_tails.moa
   wags_tails.mondo
   wags_tails.ncbi
   wags_tails.ncbi_lrg_refseqgene
   wags_tails.ncbi_mane_summary
   wags_tails.ncit
   wags_tails.oncotree
   wags_tails.rxnorm

.. _utils_modules_api_index:

Utilities
---------

.. autosummary::
   :nosignatures:
   :toctree: api/handlers/
   :template: module_summary.rst

   wags_tails.utils.downloads
   wags_tails.utils.storage
   wags_tails.utils.versioning
